function avgSpd = avgSpeed(dist,time)
% avgSpeed finds the average speed given the distance traveled and the time
% required to get there
%
% Inputs:
%   dist = The distance traveled
%   time = The time to travel a distance
%
% Outputs
%   avgSpeed = average speed
%
% Examples
%
% >>avgSpeed(100,30);
%  ans
%     = 3.33333
% 
% >>avgSpeed(30,3);
%  ans
%     = 10
% 
% >>
%
% Andrew Paulus 10-01-2007 CISC106 section 080

%Formula
avgSpd = dist / time;

return;
end